@@ -1,11 +1,7 @@
 import os
 import requests
-'''__all__ = ['directory',
-'ls',
-'run',
-'file',
-'remove',
-'download_file']'''
+import linecache
+
 class File:
   def directory(directory):
     os.chdir(directory)
@@ -39,4 +35,13 @@ class File:
       except TypeError:
         os.remove(file_name+file_exten)
         return False
+  def get_line(self,file,line_num):
+    return linecache.getline(file,line_num)
 
+class Math:
+  def fib(n):
+    list = []
+    a, b = 0, 1
+    while a < n:
+      list.append(a)
+      a, b = b, a+b
\ No newline at end of file
